@@ -1,4 +1,4 @@
-import os, boto3, subprocess, uuid, json, datetime
+import os, boto3, subprocess, uuid, json, datetime, sys
 SCRIPT_DIR = str(os.path.dirname(os.path.realpath(__file__)))
 sys.path.append(os.path.join(SCRIPT_DIR))
 from dateutil.tz import *
